/**
 * Copyright 2009-2018 PrimeTek.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.primefaces.model;

import java.util.List;

public interface ScheduleModel {

    public void addEvent(ScheduleEvent event);

    public boolean deleteEvent(ScheduleEvent event);

    public List<ScheduleEvent> getEvents();

    public ScheduleEvent getEvent(String id);

    public void updateEvent(ScheduleEvent event);

    public int getEventCount();

    public void clear();

    public boolean isEventLimit();
}
